EXPORTS
	"_._15CEmailTestUtils" @ 1 NONAME ; CEmailTestUtils::~CEmailTestUtils(void)
	CopyScriptFileL__15CEmailTestUtilsRC7TDesC16N21 @ 2 NONAME ; CEmailTestUtils::CopyScriptFileL(TDesC16 const &, TDesC16 const &, TDesC16 const &)
	CopyScriptFileL__15CEmailTestUtilsRC7TDesC16T1 @ 3 NONAME ; CEmailTestUtils::CopyScriptFileL(TDesC16 const &, TDesC16 const &)
	CreateAllTestDirectories__15CEmailTestUtils @ 4 NONAME ; CEmailTestUtils::CreateAllTestDirectories(void)
	CreateImapServerMtmRegL__15CEmailTestUtils @ 5 NONAME ; CEmailTestUtils::CreateImapServerMtmRegL(void)
	CreateImapServiceL__15CEmailTestUtils @ 6 NONAME ; CEmailTestUtils::CreateImapServiceL(void)
	CreateMessageFilesL__15CEmailTestUtilsll @ 7 NONAME ; CEmailTestUtils::CreateMessageFilesL(long, long)
	CreateMessageFilesL__15CEmailTestUtilsllRC7TDesC16 @ 8 NONAME ; CEmailTestUtils::CreateMessageFilesL(long, long, TDesC16 const &)
	CreateMessageL__15CEmailTestUtilsRC7TDesC16ll @ 9 NONAME ; CEmailTestUtils::CreateMessageL(TDesC16 const &, long, long)
	CreatePopServerMtmRegL__15CEmailTestUtils @ 10 NONAME ; CEmailTestUtils::CreatePopServerMtmRegL(void)
	CreatePopServiceL__15CEmailTestUtils @ 11 NONAME ; CEmailTestUtils::CreatePopServiceL(void)
	CreateServerMtmRegsL__15CEmailTestUtils @ 12 NONAME ; CEmailTestUtils::CreateServerMtmRegsL(void)
	CreateServicesL__15CEmailTestUtils @ 13 NONAME ; CEmailTestUtils::CreateServicesL(void)
	CreateSmtpServerMtmRegL__15CEmailTestUtils @ 14 NONAME ; CEmailTestUtils::CreateSmtpServerMtmRegL(void)
	CreateSmtpServiceL__15CEmailTestUtils @ 15 NONAME ; CEmailTestUtils::CreateSmtpServiceL(void)
	DeleteImapServiceL__15CEmailTestUtils @ 16 NONAME ; CEmailTestUtils::DeleteImapServiceL(void)
	DeletePopServiceL__15CEmailTestUtils @ 17 NONAME ; CEmailTestUtils::DeletePopServiceL(void)
	DeleteServicesL__15CEmailTestUtils @ 18 NONAME ; CEmailTestUtils::DeleteServicesL(void)
	DeleteSmtpServiceL__15CEmailTestUtils @ 19 NONAME ; CEmailTestUtils::DeleteSmtpServiceL(void)
	ErrorActualL__16CScriptTestUtils @ 20 NONAME ; CScriptTestUtils::ErrorActualL(void)
	ErrorExpectedL__16CScriptTestUtils @ 21 NONAME ; CScriptTestUtils::ErrorExpectedL(void)
	ErrorLineNumber__16CScriptTestUtils @ 22 NONAME ; CScriptTestUtils::ErrorLineNumber(void)
	FindExistingServicesL__15CEmailTestUtils @ 23 NONAME ; CEmailTestUtils::FindExistingServicesL(void)
	FindImapServiceL__15CEmailTestUtils @ 24 NONAME ; CEmailTestUtils::FindImapServiceL(void)
	FindPopServiceL__15CEmailTestUtils @ 25 NONAME ; CEmailTestUtils::FindPopServiceL(void)
	FindSmtpServiceL__15CEmailTestUtils @ 26 NONAME ; CEmailTestUtils::FindSmtpServiceL(void)
	InstallImapMtmGroupL__15CEmailTestUtils @ 27 NONAME ; CEmailTestUtils::InstallImapMtmGroupL(void)
	InstallMtmGroupsL__15CEmailTestUtils @ 28 NONAME ; CEmailTestUtils::InstallMtmGroupsL(void)
	InstallPopMtmGroupL__15CEmailTestUtils @ 29 NONAME ; CEmailTestUtils::InstallPopMtmGroupL(void)
	InstallSmtpMtmGroupL__15CEmailTestUtils @ 30 NONAME ; CEmailTestUtils::InstallSmtpMtmGroupL(void)
	InstantiateClientMtmsL__15CEmailTestUtils @ 31 NONAME ; CEmailTestUtils::InstantiateClientMtmsL(void)
	InstantiateImapClientMtmL__15CEmailTestUtils @ 32 NONAME ; CEmailTestUtils::InstantiateImapClientMtmL(void)
	InstantiateImapServerMtmL__15CEmailTestUtils @ 33 NONAME ; CEmailTestUtils::InstantiateImapServerMtmL(void)
	InstantiatePopClientMtmL__15CEmailTestUtils @ 34 NONAME ; CEmailTestUtils::InstantiatePopClientMtmL(void)
	InstantiatePopServerMtmL__15CEmailTestUtils @ 35 NONAME ; CEmailTestUtils::InstantiatePopServerMtmL(void)
	InstantiateServerMtmsL__15CEmailTestUtils @ 36 NONAME ; CEmailTestUtils::InstantiateServerMtmsL(void)
	InstantiateSmtpClientMtmL__15CEmailTestUtils @ 37 NONAME ; CEmailTestUtils::InstantiateSmtpClientMtmL(void)
	InstantiateSmtpServerMtmL__15CEmailTestUtils @ 38 NONAME ; CEmailTestUtils::InstantiateSmtpServerMtmL(void)
	ListChildrenL__15CEmailTestUtilsR5RFileR4CDirRiT3ii @ 39 NONAME ; CEmailTestUtils::ListChildrenL(RFile &, CDir &, int &, int &, int, int)
	LogToInputFileL__16CScriptTestUtilsRC7TDesC16T1i @ 40 NONAME ; CScriptTestUtils::LogToInputFileL(TDesC16 const &, TDesC16 const &, int)
	LogToOutputFileL__16CScriptTestUtilsRC7TDesC16T1i @ 41 NONAME ; CScriptTestUtils::LogToOutputFileL(TDesC16 const &, TDesC16 const &, int)
	NewLC__15CEmailTestUtilsR5RTestUi @ 42 NONAME ; CEmailTestUtils::NewLC(RTest &, unsigned int)
	NewLC__16CScriptTestUtilsR15CEmailTestUtils @ 43 NONAME ; CScriptTestUtils::NewLC(CEmailTestUtils &)
	NewL__15CEmailTestUtilsR5RTestUi @ 44 NONAME ; CEmailTestUtils::NewL(RTest &, unsigned int)
	Reset__15CEmailTestUtils @ 45 NONAME ; CEmailTestUtils::Reset(void)
	StartConnectionL__15CEmailTestUtilsUl @ 46 NONAME ; CEmailTestUtils::StartConnectionL(unsigned long)
	CheckLogOutputL__16CScriptTestUtilsiRC7TDesC16 @ 47 NONAME ; CScriptTestUtils::CheckLogOutputL(int, TDesC16 const &)
	DeleteScriptFilesFromLogsDirL__15CEmailTestUtils @ 48 NONAME R3UNUSED ; CEmailTestUtils::DeleteScriptFilesFromLogsDirL(void)

